Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3700)

Unified Diff: chrome/common/extensions/extension_messages.h

Issue 13726026: Added ActivityLog tests and associated bugfixes/extra logging. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Wrapped line Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/extensions/extension_messages.h
diff --git a/chrome/common/extensions/extension_messages.h b/chrome/common/extensions/extension_messages.h
index 32c24b3738b511701ac850a0f8820b17e954ca78..62af07adbfcc14835dae5ead7bb8ea0ec20f569e 100644
--- a/chrome/common/extensions/extension_messages.h
+++ b/chrome/common/extensions/extension_messages.h
@@ -30,8 +30,9 @@
IPC_ENUM_TRAITS(extensions::ViewType)
-// Parameters structure for ExtensionHostMsg_AddAPIActionToActivityLog.
-IPC_STRUCT_BEGIN(ExtensionHostMsg_APIAction_Params)
+// Parameters structure for ExtensionHostMsg_AddAPIActionToActivityLog and
+// ExtensionHostMsg_AddEventToActivityLog.
+IPC_STRUCT_BEGIN(ExtensionHostMsg_APIActionOrEvent_Params)
// API name.
IPC_STRUCT_MEMBER(std::string, api_call)
@@ -603,7 +604,12 @@ IPC_MESSAGE_ROUTED1(ExtensionHostMsg_UpdateDraggableRegions,
// Sent by the renderer to log an API action to the extension activity log.
IPC_MESSAGE_CONTROL2(ExtensionHostMsg_AddAPIActionToActivityLog,
std::string /* extension_id */,
- ExtensionHostMsg_APIAction_Params)
+ ExtensionHostMsg_APIActionOrEvent_Params)
+
+// Sent by the renderer to log an event to the extension activity log.
+IPC_MESSAGE_CONTROL2(ExtensionHostMsg_AddEventToActivityLog,
+ std::string /* extension_id */,
+ ExtensionHostMsg_APIActionOrEvent_Params)
// Sent by the renderer to log a DOM action to the extension activity log.
IPC_MESSAGE_CONTROL2(ExtensionHostMsg_AddDOMActionToActivityLog,

Powered by Google App Engine
This is Rietveld 408576698